@@ -2,9 +2,9 @@
 
 use crate::Versions;
 use once_cell::sync::Lazy;
-use rustc_hash::FxHashMap;
+use swc_common::collections::AHashMap;
 
-pub static DATA: Lazy<FxHashMap<String, Versions>> = Lazy::new(|| {
+pub static DATA: Lazy<AHashMap<String, Versions>> = Lazy::new(|| {
     serde_json::from_str(include_str!("compat.json"))
         .expect("failed parse corejs3-compat data.json")
 });
